==> elixir-react-native-components-1.0.0.tgz: package/screens/main.js <==
import React, { useEffect } from "react";
import PropTypes from "prop-types";
import { connect } from "react-redux";
import { Layout } from "antd";
import Sidebar from "../components/sidebar";
import Header from "../components/header";
import Tabs from "../components/tabs";
import { setMainMenu, setFavoriteItems, fetchFavoriteList, fetchMainMenu } from "elixir-react-stateful/redux/actions";
import { getMainMenu, getFavoriteItems } from "../service/localStorage";

const { Content, Footer } = Layout;

const TabsScreen = ({ isRTL, dispatch, currentUser }) => {
  useEffect(() => {
    dispatch(setMainMenu(getMainMenu(currentUser)));
    dispatch(setFavoriteItems(getFavoriteItems(currentUser)));
    dispatch(fetchFavoriteList());
    dispatch(fetchMainMenu());
  }, []);
  return (
    <Layout>
      <Sidebar />
      <Layout
        className="site-layout"
        style={{
          [isRTL ? "marginRight" : "marginLeft"]: 65,
        }}
      >
        <Header />
        <Content style={{ marginTop: "1em", overflow: "initial" }}>
          <div
            className="site-layout-background"
            style={{ textAlign: "center", minHeight: "85vh", padding: "1em" }}
          >
            <Tabs />
          </div>
        </Content>
        <Footer className="footer">
          <a href="http://el-ixir.com/" target="_blank" rel="noopener noreferrer">
            Copyright Elixir ® Intelligent Software {new Date().getFullYear()}. All rights reserved
          </a>
        </Footer>
      </Layout>
    </Layout>
  );
};

TabsScreen.propTypes = {
  dispatch: PropTypes.func.isRequired,
  isRTL: PropTypes.bool.isRequired,
  currentUser: PropTypes.shape({ username: PropTypes.string, agency: PropTypes.string }).isRequired,
};

const mapStateToProps = (state) => ({
  isRTL: state.general.isRTL,
  currentUser: state.general.currentUser,
});

//export default connect(mapStateToProps)(TabsScreen);
export default TabsScreen;

==> elixir-react-native-components-1.2.0.tgz: package/screens/main.js <==
import React, { useEffect } from "react";
import PropTypes from "prop-types";
import { connect } from "react-redux";
import { Layout } from "antd";
import Sidebar from "../components/sidebar";
import Header from "../components/header";
import Tabs from "../components/tabs";
import { setMainMenu, setFavoriteItems, fetchFavoriteList, fetchMainMenu } from "@muhammadz/elixir-react-stateful/redux/actions";
import { getMainMenu, getFavoriteItems } from "../service/localStorage";

const { Content, Footer } = Layout;

const TabsScreen = ({ isRTL, dispatch, currentUser }) => {
  useEffect(() => {
    dispatch(setMainMenu(getMainMenu(currentUser)));
    dispatch(setFavoriteItems(getFavoriteItems(currentUser)));
    dispatch(fetchFavoriteList());
    dispatch(fetchMainMenu());
  }, []);
  return (
    <Layout>
      <Sidebar />
      <Layout
        className="site-layout"
        style={{
          [isRTL ? "marginRight" : "marginLeft"]: 65,
        }}
      >
        <Header />
        <Content style={{ marginTop: "1em", overflow: "initial" }}>
          <div
            className="site-layout-background"
            style={{ textAlign: "center", minHeight: "85vh", padding: "1em" }}
          >
            <Tabs />
          </div>
        </Content>
        <Footer className="footer">
          <a href="http://el-ixir.com/" target="_blank" rel="noopener noreferrer">
            Copyright Elixir ® Intelligent Software {new Date().getFullYear()}. All rights reserved
          </a>
        </Footer>
      </Layout>
    </Layout>
  );
};

TabsScreen.propTypes = {
  dispatch: PropTypes.func.isRequired,
  isRTL: PropTypes.bool.isRequired,
  currentUser: PropTypes.shape({ username: PropTypes.string, agency: PropTypes.string }).isRequired,
};

const mapStateToProps = (state) => ({
  isRTL: state.general.isRTL,
  currentUser: state.general.currentUser,
});

//export default connect(mapStateToProps)(TabsScreen);
export default TabsScreen;
